# OCRticle

GUI application capable of extracting text from an image, while keeping the text's original structure. OCRticle works best with articles (hence the name), but it should function with any kind of text.

## Installation

OCRticle requires Python >= 3.10 and the Tesseract OCR engine. Instructions for installing Tesseract can be found [here](https://tesseract-ocr.github.io/tessdoc/Installation.html).

Linux users should be able to install OCRticle by just running:

```
pip install ocrticle
```

For Windows users, a pre-compiled binary can be downloaded from [here](https://github.com/RisingFisan/Projeto-PI/releases/).
